@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 #*******************************************************************************
-# Copyright (c) 2005, 2006 IBM Corporation, Wind River Systems, Inc. and others.
+# Copyright (c) 2005, 2008 IBM Corporation, Wind River Systems, Inc. and others.
 # All rights reserved. This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v1.0
 # which accompanies this distribution, and is available at
@@ -26,7 +26,7 @@ $ENV{A_PLUGIN_PATH}="$plugins_dir/";
 $oldClasspath = $ENV{CLASSPATH};
 
 
-$ENV{"CLASSPATH"}="$plugins_dir:$plugins_dir/dstore_extra_server.jar:$plugins_dir/dstore_core.jar:$plugins_dir/dstore_miners.jar:$plugins_dir/clientserver.jar:$plugins_dir/cdtminer.jar:$plugins_dir/cdtmodel.jar:$plugins_dir/cdtparser.jar:$plugins_dir/org.eclipse.core.runtime_3.4.0.v20080512.jar:$plugins_dir/org.eclipse.equinox.common_3.4.0.v20080421-2006.jar:$plugins_dir/org.eclipse.core.filesystem_1.2.0.v20080604-1400.jar:$plugins_dir/stubs.jar:$plugins_dir/lrparser.jar:$plugins_dir/xlcparser.jar:$plugins_dir/net.sourceforge.lpg.lpgjavaruntime_1.1.0.v200803061910.jar:$oldClasspath";
+$ENV{"CLASSPATH"}="$plugins_dir:$plugins_dir/dstore_extra_server.jar:$plugins_dir/dstore_core.jar:$plugins_dir/dstore_miners.jar:$plugins_dir/clientserver.jar:$plugins_dir/cdtminer.jar:$plugins_dir/cdtmodel.jar:$plugins_dir/cdtparser.jar:$plugins_dir/org.eclipse.core.runtime_3.5.0.v20090525.jar:$plugins_dir/org.eclipse.equinox.common_3.5.0.v20090520-1800.jar:$plugins_dir/org.eclipse.core.filesystem_1.2.0.v20090507.jar:$plugins_dir/com.ibm.icu.base_4.0.1.v20090415.jar:$plugins_dir/stubs.jar:$plugins_dir/lrparser.jar:$plugins_dir/xlcparser.jar:$plugins_dir/net.sourceforge.lpg.lpgjavaruntime_1.1.0.v200803061910.jar:$oldClasspath";
 
 if (!defined($timeout))
 {
